# ion-channel-python-sdk

This is a Python SDK for the Ion Channel Application Programming Interface

Note: This SDK package is still in an alpha development stage - use cautiously

Installation: pip install pyonic

![Black](https://github.com/ion-channel/ion-channel-python-sdk/actions/workflows/black.yml/badge.svg)
